Class: Aws::Account::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Account::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-account/client.rb,
sig/client.rbs
Overview
An API client for Account. To construct a client, you need to configure a :region and :credentials.
client = Aws::Account::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptPrimaryEmailUpdateResponseSuccess, _GetAccountInformationResponseSuccess, _GetAlternateContactResponseSuccess, _GetContactInformationResponseSuccess, _GetGovCloudAccountInformationResponseSuccess, _GetPrimaryEmailResponseSuccess, _GetRegionOptStatusResponseSuccess, _ListRegionsResponseSuccess, _StartPrimaryEmailUpdateResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_primary_email_update(params = {}) ⇒ Types::AcceptPrimaryEmailUpdateResponse
Accepts the request that originated from StartPrimaryEmailUpdate to update the primary email address (also known as the root user email address) for the specified account.
-
#delete_alternate_contact(params = {}) ⇒ Struct
Deletes the specified alternate contact from an Amazon Web Services account.
-
#disable_region(params = {}) ⇒ Struct
Disables (opts-out) a particular Region for an account.
-
#enable_region(params = {}) ⇒ Struct
Enables (opts-in) a particular Region for an account.
-
#get_account_information(params = {}) ⇒ Types::GetAccountInformationResponse
Retrieves information about the specified account including its account name, account ID, account creation date and time, and account state.
-
#get_alternate_contact(params = {}) ⇒ Types::GetAlternateContactResponse
Retrieves the specified alternate contact attached to an Amazon Web Services account.
-
#get_contact_information(params = {}) ⇒ Types::GetContactInformationResponse
Retrieves the primary contact information of an Amazon Web Services account.
-
#get_gov_cloud_account_information(params = {}) ⇒ Types::GetGovCloudAccountInformationResponse
Retrieves information about the GovCloud account linked to the specified standard account (if it exists) including the GovCloud account ID and state.
-
#get_primary_email(params = {}) ⇒ Types::GetPrimaryEmailResponse
Retrieves the primary email address for the specified account.
-
#get_region_opt_status(params = {}) ⇒ Types::GetRegionOptStatusResponse
Retrieves the opt-in status of a particular Region.
-
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Lists all the Regions for a given account and their respective opt-in statuses.
-
#put_account_name(params = {}) ⇒ Struct
Updates the account name of the specified account.
-
#put_alternate_contact(params = {}) ⇒ Struct
Modifies the specified alternate contact attached to an Amazon Web Services account.
-
#put_contact_information(params = {}) ⇒ Struct
Updates the primary contact information of an Amazon Web Services account.
-
#start_primary_email_update(params = {}) ⇒ Types::StartPrimaryEmailUpdateResponse
Starts the process to update the primary email address for the specified account.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-account/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1553 1554 1555 |
# File 'lib/aws-sdk-account/client.rb', line 1553 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1556 1557 1558 |
# File 'lib/aws-sdk-account/client.rb', line 1556 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_primary_email_update(params = {}) ⇒ Types::AcceptPrimaryEmailUpdateResponse
Accepts the request that originated from StartPrimaryEmailUpdate to update the primary email address (also known as the root user email address) for the specified account.
86 |
# File 'sig/client.rbs', line 86
def accept_primary_email_update: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 |
# File 'lib/aws-sdk-account/client.rb', line 1526 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Account') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-account' context[:gem_version] = '1.61.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_alternate_contact(params = {}) ⇒ Struct
Deletes the specified alternate contact from an Amazon Web Services account.
For complete details about how to use the alternate contact operations, see Update the alternate contacts for your Amazon Web Services account.
94 |
# File 'sig/client.rbs', line 94
def delete_alternate_contact: (
|
#disable_region(params = {}) ⇒ Struct
Disables (opts-out) a particular Region for an account.
101 |
# File 'sig/client.rbs', line 101
def disable_region: (
|
#enable_region(params = {}) ⇒ Struct
Enables (opts-in) a particular Region for an account.
108 |
# File 'sig/client.rbs', line 108
def enable_region: (
|
#get_account_information(params = {}) ⇒ Types::GetAccountInformationResponse
Retrieves information about the specified account including its
account name, account ID, account creation date and time, and account
state. To use this API, an IAM user or role must have the
account:GetAccountInformation IAM permission.
122 |
# File 'sig/client.rbs', line 122
def get_account_information: (
|
#get_alternate_contact(params = {}) ⇒ Types::GetAlternateContactResponse
Retrieves the specified alternate contact attached to an Amazon Web Services account.
For complete details about how to use the alternate contact operations, see Update the alternate contacts for your Amazon Web Services account.
132 |
# File 'sig/client.rbs', line 132
def get_alternate_contact: (
|
#get_contact_information(params = {}) ⇒ Types::GetContactInformationResponse
Retrieves the primary contact information of an Amazon Web Services account.
For complete details about how to use the primary contact operations, see Update the primary contact for your Amazon Web Services account.
143 |
# File 'sig/client.rbs', line 143
def get_contact_information: (
|
#get_gov_cloud_account_information(params = {}) ⇒ Types::GetGovCloudAccountInformationResponse
Retrieves information about the GovCloud account linked to the
specified standard account (if it exists) including the GovCloud
account ID and state. To use this API, an IAM user or role must have
the account:GetGovCloudAccountInformation IAM permission.
154 |
# File 'sig/client.rbs', line 154
def get_gov_cloud_account_information: (
|
#get_primary_email(params = {}) ⇒ Types::GetPrimaryEmailResponse
Retrieves the primary email address for the specified account.
164 |
# File 'sig/client.rbs', line 164
def get_primary_email: (
|
#get_region_opt_status(params = {}) ⇒ Types::GetRegionOptStatusResponse
Retrieves the opt-in status of a particular Region.
175 |
# File 'sig/client.rbs', line 175
def get_region_opt_status: (
|
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Lists all the Regions for a given account and their respective opt-in
statuses. Optionally, this list can be filtered by the
region-opt-status-contains parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
187 |
# File 'sig/client.rbs', line 187
def list_regions: (
|
#put_account_name(params = {}) ⇒ Struct
Updates the account name of the specified account. To use this API,
IAM principals must have the account:PutAccountName IAM permission.
196 |
# File 'sig/client.rbs', line 196
def put_account_name: (
|
#put_alternate_contact(params = {}) ⇒ Struct
Modifies the specified alternate contact attached to an Amazon Web Services account.
For complete details about how to use the alternate contact operations, see Update the alternate contacts for your Amazon Web Services account.
203 |
# File 'sig/client.rbs', line 203
def put_alternate_contact: (
|
#put_contact_information(params = {}) ⇒ Struct
Updates the primary contact information of an Amazon Web Services account.
For complete details about how to use the primary contact operations, see Update the primary contact for your Amazon Web Services account.
214 |
# File 'sig/client.rbs', line 214
def put_contact_information: (
|
#start_primary_email_update(params = {}) ⇒ Types::StartPrimaryEmailUpdateResponse
Starts the process to update the primary email address for the specified account.
238 |
# File 'sig/client.rbs', line 238
def start_primary_email_update: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1546 1547 1548 |
# File 'lib/aws-sdk-account/client.rb', line 1546 def waiter_names [] end |