Class: Aws::Account::Types::GetAccountInformationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-account/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:account_name]

Instance Attribute Summary collapse

Instance Attribute Details

#account_created_dateTime

The date and time the account was created.

Returns:

  • (Time)


468
469
470
471
472
473
474
475
# File 'lib/aws-sdk-account/types.rb', line 468

class GetAccountInformationResponse < Struct.new(
  :account_id,
  :account_name,
  :account_created_date,
  :account_state)
  SENSITIVE = [:account_name]
  include Aws::Structure
end

#account_idString

Specifies the 12-digit account ID number of the Amazon Web Services account that you want to access or modify with this operation. To use this parameter, the caller must be an identity in the organization's management account or a delegated administrator account. The specified account ID must be a member account in the same organization. The organization must have all features enabled, and the organization must have trusted access enabled for the Account Management service, and optionally a delegated admin account assigned.

This operation can only be called from the management account or the delegated administrator account of an organization for a member account.

The management account can't specify its own AccountId.

Returns:

  • (String)


468
469
470
471
472
473
474
475
# File 'lib/aws-sdk-account/types.rb', line 468

class GetAccountInformationResponse < Struct.new(
  :account_id,
  :account_name,
  :account_created_date,
  :account_state)
  SENSITIVE = [:account_name]
  include Aws::Structure
end

#account_nameString

The name of the account.

Returns:

  • (String)


468
469
470
471
472
473
474
475
# File 'lib/aws-sdk-account/types.rb', line 468

class GetAccountInformationResponse < Struct.new(
  :account_id,
  :account_name,
  :account_created_date,
  :account_state)
  SENSITIVE = [:account_name]
  include Aws::Structure
end

#account_stateString

The state of the account. Each account state represents a specific phase in the account lifecycle. Use this information to manage account access, automate workflows, or trigger actions based on account state changes.

Valid values: PENDING_ACTIVATION | ACTIVE | SUSPENDED | CLOSED

Returns:

  • (String)


468
469
470
471
472
473
474
475
# File 'lib/aws-sdk-account/types.rb', line 468

class GetAccountInformationResponse < Struct.new(
  :account_id,
  :account_name,
  :account_created_date,
  :account_state)
  SENSITIVE = [:account_name]
  include Aws::Structure
end