Class: Aws::Account::Types::GetPrimaryEmailUpdateStatusResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-account/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#statusString

The status of the most recent primary email update request.

Returns:

  • (String)


743
744
745
746
747
748
# File 'lib/aws-sdk-account/types.rb', line 743

class GetPrimaryEmailUpdateStatusResponse < Struct.new(
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time that the most recent primary email update status was last changed.

Returns:

  • (Time)


743
744
745
746
747
748
# File 'lib/aws-sdk-account/types.rb', line 743

class GetPrimaryEmailUpdateStatusResponse < Struct.new(
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end