Class: Aws::Account::Types::ListRegionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Account::Types::ListRegionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-account/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
Specifies the 12-digit account ID number of the Amazon Web Services account that you want to access or modify with this operation.
-
#max_results ⇒ Integer
The total number of items to return in the command’s output.
-
#next_token ⇒ String
A token used to specify where to start paginating.
-
#region_opt_status_contains ⇒ Array<String>
A list of Region statuses (Enabling, Enabled, Disabling, Disabled, Enabled_by_default) to use to filter the list of Regions for a given account.
Instance Attribute Details
#account_id ⇒ String
Specifies the 12-digit account ID number of the Amazon Web Services account that you want to access or modify with this operation. If you don't specify this parameter, it defaults to the Amazon Web Services account of the identity used to call the operation. To use this parameter, the caller must be an identity in the organization's management account or a delegated administrator account. The specified account ID must be a member account in the same organization. The organization must have all features enabled, and the organization must have trusted access enabled for the Account Management service, and optionally a delegated admin account assigned.
AccountId. It must
call the operation in standalone context by not including the
AccountId parameter.
To call this operation on an account that is not a member of an organization, don't specify this parameter. Instead, call the operation using an identity belonging to the account whose contacts you wish to retrieve or modify.
902 903 904 905 906 907 908 909 |
# File 'lib/aws-sdk-account/types.rb', line 902 class ListRegionsRequest < Struct.new( :account_id, :max_results, :next_token, :region_opt_status_contains) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The total number of items to return in the command’s output. If the
total number of items available is more than the value specified, a
NextToken is provided in the command’s output. To resume
pagination, provide the NextToken value in the starting-token
argument of a subsequent command. Do not use the NextToken
response element directly outside of the Amazon Web Services CLI.
For usage examples, see Pagination in the Amazon Web Services
Command Line Interface User Guide.
902 903 904 905 906 907 908 909 |
# File 'lib/aws-sdk-account/types.rb', line 902 class ListRegionsRequest < Struct.new( :account_id, :max_results, :next_token, :region_opt_status_contains) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token used to specify where to start paginating. This is the
NextToken from a previously truncated response. For usage
examples, see Pagination in the Amazon Web Services Command
Line Interface User Guide.
902 903 904 905 906 907 908 909 |
# File 'lib/aws-sdk-account/types.rb', line 902 class ListRegionsRequest < Struct.new( :account_id, :max_results, :next_token, :region_opt_status_contains) SENSITIVE = [] include Aws::Structure end |
#region_opt_status_contains ⇒ Array<String>
A list of Region statuses (Enabling, Enabled, Disabling, Disabled, Enabled_by_default) to use to filter the list of Regions for a given account. For example, passing in a value of ENABLING will only return a list of Regions with a Region status of ENABLING.
902 903 904 905 906 907 908 909 |
# File 'lib/aws-sdk-account/types.rb', line 902 class ListRegionsRequest < Struct.new( :account_id, :max_results, :next_token, :region_opt_status_contains) SENSITIVE = [] include Aws::Structure end |