Class: Aws::Account::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Account::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-account/types.rb
Overview
The operation failed because one of the input parameters was invalid.
Constant Summary collapse
- SENSITIVE =
[:message]
Instance Attribute Summary collapse
-
#field_list ⇒ Array<Types::ValidationExceptionField>
The field where the invalid entry was detected.
-
#message ⇒ String
The message that informs you about what was invalid about the request.
-
#reason ⇒ String
The reason that validation failed.
Instance Attribute Details
#field_list ⇒ Array<Types::ValidationExceptionField>
The field where the invalid entry was detected.
1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-account/types.rb', line 1243 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [:message] include Aws::Structure end |
#message ⇒ String
The message that informs you about what was invalid about the request.
1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-account/types.rb', line 1243 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [:message] include Aws::Structure end |
#reason ⇒ String
The reason that validation failed.
1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/aws-sdk-account/types.rb', line 1243 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [:message] include Aws::Structure end |