Class: Aws::Account::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Account::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-account/client.rb
Overview
An API client for Account. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Account::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_primary_email_update(params = {}) ⇒ Types::AcceptPrimaryEmailUpdateResponse
Accepts the request that originated from StartPrimaryEmailUpdate to update the primary email address (also known as the root user email address) for the specified account.
-
#delete_alternate_contact(params = {}) ⇒ Struct
Deletes the specified alternate contact from an Amazon Web Services account.
-
#disable_region(params = {}) ⇒ Struct
Disables (opts-out) a particular Region for an account.
-
#enable_region(params = {}) ⇒ Struct
Enables (opts-in) a particular Region for an account.
-
#get_account_information(params = {}) ⇒ Types::GetAccountInformationResponse
Retrieves information about the specified account including its account name, account ID, account creation date and time, and account state.
-
#get_alternate_contact(params = {}) ⇒ Types::GetAlternateContactResponse
Retrieves the specified alternate contact attached to an Amazon Web Services account.
-
#get_contact_information(params = {}) ⇒ Types::GetContactInformationResponse
Retrieves the primary contact information of an Amazon Web Services account.
-
#get_gov_cloud_account_information(params = {}) ⇒ Types::GetGovCloudAccountInformationResponse
Retrieves information about the GovCloud account linked to the specified standard account (if it exists) including the GovCloud account ID and state.
-
#get_primary_email(params = {}) ⇒ Types::GetPrimaryEmailResponse
Retrieves the primary email address for the specified account.
-
#get_region_opt_status(params = {}) ⇒ Types::GetRegionOptStatusResponse
Retrieves the opt-in status of a particular Region.
-
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Lists all the Regions for a given account and their respective opt-in statuses.
-
#put_account_name(params = {}) ⇒ Struct
Updates the account name of the specified account.
-
#put_alternate_contact(params = {}) ⇒ Struct
Modifies the specified alternate contact attached to an Amazon Web Services account.
-
#put_contact_information(params = {}) ⇒ Struct
Updates the primary contact information of an Amazon Web Services account.
-
#start_primary_email_update(params = {}) ⇒ Types::StartPrimaryEmailUpdateResponse
Starts the process to update the primary email address for the specified account.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-account/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1555 1556 1557 |
# File 'lib/aws-sdk-account/client.rb', line 1555 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1558 1559 1560 |
# File 'lib/aws-sdk-account/client.rb', line 1558 def errors_module Errors end |
Instance Method Details
#accept_primary_email_update(params = {}) ⇒ Types::AcceptPrimaryEmailUpdateResponse
Accepts the request that originated from StartPrimaryEmailUpdate to update the primary email address (also known as the root user email address) for the specified account.
538 539 540 541 |
# File 'lib/aws-sdk-account/client.rb', line 538 def accept_primary_email_update(params = {}, = {}) req = build_request(:accept_primary_email_update, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 |
# File 'lib/aws-sdk-account/client.rb', line 1528 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Account') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-account' context[:gem_version] = '1.57.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_alternate_contact(params = {}) ⇒ Struct
Deletes the specified alternate contact from an Amazon Web Services account.
For complete details about how to use the alternate contact operations, see [Update the alternate contacts for your Amazon Web Services account].
<note markdown=“1”> Before you can update the alternate contact information for an Amazon Web Services account that is managed by Organizations, you must first enable integration between Amazon Web Services Account Management and Organizations. For more information, see [Enable trusted access for Amazon Web Services Account Management].
</note>
[1]: docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact-alternate.html [2]: docs.aws.amazon.com/accounts/latest/reference/using-orgs-trusted-access.html
612 613 614 615 |
# File 'lib/aws-sdk-account/client.rb', line 612 def delete_alternate_contact(params = {}, = {}) req = build_request(:delete_alternate_contact, params) req.send_request() end |
#disable_region(params = {}) ⇒ Struct
Disables (opts-out) a particular Region for an account.
<note markdown=“1”> The act of disabling a Region will remove all IAM access to any resources that reside in that Region.
</note>
676 677 678 679 |
# File 'lib/aws-sdk-account/client.rb', line 676 def disable_region(params = {}, = {}) req = build_request(:disable_region, params) req.send_request() end |
#enable_region(params = {}) ⇒ Struct
Enables (opts-in) a particular Region for an account.
736 737 738 739 |
# File 'lib/aws-sdk-account/client.rb', line 736 def enable_region(params = {}, = {}) req = build_request(:enable_region, params) req.send_request() end |
#get_account_information(params = {}) ⇒ Types::GetAccountInformationResponse
Retrieves information about the specified account including its account name, account ID, account creation date and time, and account state. To use this API, an IAM user or role must have the ‘account:GetAccountInformation` IAM permission.
803 804 805 806 |
# File 'lib/aws-sdk-account/client.rb', line 803 def get_account_information(params = {}, = {}) req = build_request(:get_account_information, params) req.send_request() end |
#get_alternate_contact(params = {}) ⇒ Types::GetAlternateContactResponse
Retrieves the specified alternate contact attached to an Amazon Web Services account.
For complete details about how to use the alternate contact operations, see [Update the alternate contacts for your Amazon Web Services account].
<note markdown=“1”> Before you can update the alternate contact information for an Amazon Web Services account that is managed by Organizations, you must first enable integration between Amazon Web Services Account Management and Organizations. For more information, see [Enable trusted access for Amazon Web Services Account Management].
</note>
[1]: docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact-alternate.html [2]: docs.aws.amazon.com/accounts/latest/reference/using-orgs-trusted-access.html
887 888 889 890 |
# File 'lib/aws-sdk-account/client.rb', line 887 def get_alternate_contact(params = {}, = {}) req = build_request(:get_alternate_contact, params) req.send_request() end |
#get_contact_information(params = {}) ⇒ Types::GetContactInformationResponse
Retrieves the primary contact information of an Amazon Web Services account.
For complete details about how to use the primary contact operations, see [Update the primary contact for your Amazon Web Services account].
[1]: docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact-primary.html
963 964 965 966 |
# File 'lib/aws-sdk-account/client.rb', line 963 def get_contact_information(params = {}, = {}) req = build_request(:get_contact_information, params) req.send_request() end |
#get_gov_cloud_account_information(params = {}) ⇒ Types::GetGovCloudAccountInformationResponse
Retrieves information about the GovCloud account linked to the specified standard account (if it exists) including the GovCloud account ID and state. To use this API, an IAM user or role must have the ‘account:GetGovCloudAccountInformation` IAM permission.
1026 1027 1028 1029 |
# File 'lib/aws-sdk-account/client.rb', line 1026 def get_gov_cloud_account_information(params = {}, = {}) req = build_request(:get_gov_cloud_account_information, params) req.send_request() end |
#get_primary_email(params = {}) ⇒ Types::GetPrimaryEmailResponse
Retrieves the primary email address for the specified account.
1077 1078 1079 1080 |
# File 'lib/aws-sdk-account/client.rb', line 1077 def get_primary_email(params = {}, = {}) req = build_request(:get_primary_email, params) req.send_request() end |
#get_region_opt_status(params = {}) ⇒ Types::GetRegionOptStatusResponse
Retrieves the opt-in status of a particular Region.
1141 1142 1143 1144 |
# File 'lib/aws-sdk-account/client.rb', line 1141 def get_region_opt_status(params = {}, = {}) req = build_request(:get_region_opt_status, params) req.send_request() end |
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Lists all the Regions for a given account and their respective opt-in statuses. Optionally, this list can be filtered by the ‘region-opt-status-contains` parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1238 1239 1240 1241 |
# File 'lib/aws-sdk-account/client.rb', line 1238 def list_regions(params = {}, = {}) req = build_request(:list_regions, params) req.send_request() end |
#put_account_name(params = {}) ⇒ Struct
Updates the account name of the specified account. To use this API, IAM principals must have the ‘account:PutAccountName` IAM permission.
1295 1296 1297 1298 |
# File 'lib/aws-sdk-account/client.rb', line 1295 def put_account_name(params = {}, = {}) req = build_request(:put_account_name, params) req.send_request() end |
#put_alternate_contact(params = {}) ⇒ Struct
Modifies the specified alternate contact attached to an Amazon Web Services account.
For complete details about how to use the alternate contact operations, see [Update the alternate contacts for your Amazon Web Services account].
<note markdown=“1”> Before you can update the alternate contact information for an Amazon Web Services account that is managed by Organizations, you must first enable integration between Amazon Web Services Account Management and Organizations. For more information, see [Enable trusted access for Amazon Web Services Account Management].
</note>
[1]: docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact-alternate.html [2]: docs.aws.amazon.com/accounts/latest/reference/using-orgs-trusted-access.html
1385 1386 1387 1388 |
# File 'lib/aws-sdk-account/client.rb', line 1385 def put_alternate_contact(params = {}, = {}) req = build_request(:put_alternate_contact, params) req.send_request() end |
#put_contact_information(params = {}) ⇒ Struct
Updates the primary contact information of an Amazon Web Services account.
For complete details about how to use the primary contact operations, see [Update the primary contact for your Amazon Web Services account].
[1]: docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact-primary.html
1462 1463 1464 1465 |
# File 'lib/aws-sdk-account/client.rb', line 1462 def put_contact_information(params = {}, = {}) req = build_request(:put_contact_information, params) req.send_request() end |
#start_primary_email_update(params = {}) ⇒ Types::StartPrimaryEmailUpdateResponse
Starts the process to update the primary email address for the specified account.
1519 1520 1521 1522 |
# File 'lib/aws-sdk-account/client.rb', line 1519 def start_primary_email_update(params = {}, = {}) req = build_request(:start_primary_email_update, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1548 1549 1550 |
# File 'lib/aws-sdk-account/client.rb', line 1548 def waiter_names [] end |