Class: Aws::Account::Types::GetAccountInformationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Account::Types::GetAccountInformationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-account/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:account_name]
Instance Attribute Summary collapse
-
#account_created_date ⇒ Time
The date and time the account was created.
-
#account_id ⇒ String
Specifies the 12-digit account ID number of the Amazon Web Services account that you want to access or modify with this operation.
-
#account_name ⇒ String
The name of the account.
-
#account_state ⇒ String
The state of the account.
Instance Attribute Details
#account_created_date ⇒ Time
The date and time the account was created.
468 469 470 471 472 473 474 475 |
# File 'lib/aws-sdk-account/types.rb', line 468 class GetAccountInformationResponse < Struct.new( :account_id, :account_name, :account_created_date, :account_state) SENSITIVE = [:account_name] include Aws::Structure end |
#account_id ⇒ String
Specifies the 12-digit account ID number of the Amazon Web Services account that you want to access or modify with this operation. To use this parameter, the caller must be an identity in the
- organization’s management account][1
-
or a delegated administrator
account. The specified account ID must be a member account in the same organization. The organization must have [all features enabled], and the organization must have [trusted access] enabled for the Account Management service, and optionally a
- delegated admin][4
-
account assigned.
This operation can only be called from the management account or the delegated administrator account of an organization for a member account.
<note markdown=“1”> The management account can’t specify its own ‘AccountId`.
</note>
[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#account [2]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_support-all-features.html [3]: docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services.html [4]: docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#delegated-admin
468 469 470 471 472 473 474 475 |
# File 'lib/aws-sdk-account/types.rb', line 468 class GetAccountInformationResponse < Struct.new( :account_id, :account_name, :account_created_date, :account_state) SENSITIVE = [:account_name] include Aws::Structure end |
#account_name ⇒ String
The name of the account.
468 469 470 471 472 473 474 475 |
# File 'lib/aws-sdk-account/types.rb', line 468 class GetAccountInformationResponse < Struct.new( :account_id, :account_name, :account_created_date, :account_state) SENSITIVE = [:account_name] include Aws::Structure end |
#account_state ⇒ String
The state of the account. Each account state represents a specific phase in the account lifecycle. Use this information to manage account access, automate workflows, or trigger actions based on account state changes.
Valid values: ‘PENDING_ACTIVATION | ACTIVE | SUSPENDED | CLOSED`
468 469 470 471 472 473 474 475 |
# File 'lib/aws-sdk-account/types.rb', line 468 class GetAccountInformationResponse < Struct.new( :account_id, :account_name, :account_created_date, :account_state) SENSITIVE = [:account_name] include Aws::Structure end |